"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetaStorage = void 0;
class MetaStorage {
    constructor() {
        this._typeMetadatas = new Map();
        this._transformerMetadata = new Map();
    }
    static instance() {
        return MetaStorage._metaStorage
            ? MetaStorage._metaStorage
            : (MetaStorage._metaStorage = new MetaStorage());
    }
    records() {
        return Array.from(this._transformerMetadata.values());
    }
    addTransformerMetadata(metadata) {
        this._initializeOrSkip(metadata.target);
        const _metadataRecords = this._metaRecordsFor(metadata.target);
        this._detectAndThrowDuplicateTransformers(_metadataRecords, metadata);
        _metadataRecords.push(metadata);
    }
    findTransformerMetadata(target) {
        if (!this._transformerMetadata.has(target)) {
            return undefined;
        }
        return this._transformerMetadata.get(target);
    }
    addTypeMetadata(metadata) {
        if (!this._typeMetadatas.has(metadata.target)) {
            this._typeMetadatas.set(metadata.target, new Map());
        }
        this._typeMetadatas
            .get(metadata.target)
            .set(metadata.propertyName, metadata);
    }
    findTypeMetadata(target, propertyName) {
        if (!this._typeMetadatas.has(target)) {
            return undefined;
        }
        return this._typeMetadatas.get(target).get(propertyName);
    }
    _initializeOrSkip(target) {
        if (!this._transformerMetadata.has(target)) {
            this._transformerMetadata.set(target, []);
        }
    }
    _metaRecordsFor(target) {
        return this._transformerMetadata.get(target);
    }
    _detectAndThrowDuplicateTransformers(records, newRecord) {
        if (records.some((meta) => meta.propertyName === newRecord.propertyName)) {
            throw {
                message: "You can't use multiple transformers for the same property",
            };
        }
    }
}
exports.MetaStorage = MetaStorage;
